@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.0';
+our $VERSION = '1.1';
 
 use Email::Store::DBI;
 use base 'Email::Store::DBI';
@@ -14,11 +14,11 @@ use Time::Piece;
 use Date::Parse;
 
 Email::Store::Date->table("mail_date");
-Email::Store::Date->columns(All => qw/mail date/);
+Email::Store::Date->columns(All => qw/mail date year month day/);
 Email::Store::Date->columns(Primary => qw/mail/);
 Email::Store::Date->has_a( date => 'Time::Piece' );
 Email::Store::Date->has_a( mail => "Email::Store::Mail" );
-Email::Store::Mail->might_have( mail_date => "Email::Store::Date" => 'date');
+Email::Store::Mail->might_have( mail_date => "Email::Store::Date" => qw(date year month day));
 
 
 
@@ -27,11 +27,14 @@ sub on_store_order { 80 }
 sub on_store {
     my ($self, $mail) = @_;
     my $simple = $mail->simple;
-	my $date   = $simple->header('date')
+
+    my $date   = $simple->header('date')
                  || _get_date_in_received_header($simple)
                  || $simple->header('resent-date');
-	my $time   = str2time($date);
-	Email::Store::Date->create( { mail => $mail->id, date => $time } );
+
+    my $time   = str2time($date);
+    my $tp     = Time::Piece->new($time);
+    Email::Store::Date->create( { mail => $mail->id, date => $time, year => $tp->year, month => $tp->mon, day => $tp->mday } );
 
 }
 
@@ -42,6 +45,7 @@ sub _get_date_in_received_header {
     $date =~ s/.*;// and return $date;
 }
 
+
 sub on_gather_plucene_fields_order { 80 }
 sub on_gather_plucene_fields {
     my ($self, $mail, $hash) = @_;
@@ -63,9 +67,20 @@ Remember to create the database table:
 
 And now:
 
-	print $mail->date->ymd,"\n";
+    print $mail->date->ymd,"\n";
 
-=head1 DESCRIPTION
+or
+
+    $mail->year;
+    $mail->month;
+    $mail->day;
+
+You can also search for all mails between two unix epochs
+
+    # get all mails in the last day
+    my $time = time();
+    my $day  = 24*60*60;
+	Email::Store::Mail->search_between($time, $time-$day);
 
 =head1 SEE ALSO
 
@@ -79,9 +94,23 @@ This module is distributed under the same terms as Perl itself.
 
 =cut
 
+
+Email::Store::Mail->set_sql(between => qq{
+    SELECT mail.message_id
+    FROM mail_date, mail
+    WHERE mail.message_id = mail_date.mail AND
+    mail_date.date >= ? AND
+    mail_date.date <=  ?
+    ORDER BY mail_date.date DESC
+});
+
+
 1;
 __DATA__
 CREATE TABLE IF NOT EXISTS mail_date (
     mail varchar(255) NOT NULL PRIMARY KEY,                                                 
-	date int
+    date  int,
+    year  int,
+    month int,
+    day   int
 );
